@@ -169,6 +169,18 @@ class IsNextWithSpace(Criteria):
         return False
 
 
+class IsNextWithEndQuota(Criteria):
+    def __init__(self, symbols: dict):
+        super(IsNextWithEndQuota, self).__init__('IsNextWithQuota', symbols)
+
+    def accept(self, state: StrSequence) -> bool:
+        if self.symbols['quotation_right'].match(state.next_value):
+            return True
+        elif self.symbols['quotation_en'].match(state.next_value):  # and (state.quota_en + state.quota_left)%2 != 0
+            return True
+        return False
+
+
 # =========================== #
 #      Special Condition      #
 # =========================== #
