@@ -109,6 +109,7 @@ class LongHandlerEN(Operation):
         self.is_right_quota = condition.IsRightQuotaEn(symbols)
         self.not_in_white_list = condition.NotInWhitelistDotEn()
         self.is_next_with_space = condition.IsNextWithSpace(symbols)
+        self.is_next_with_quota = condition.IsNextWithEndQuota(symbols)
         self.min_sentence_length = min_sentence_length
         self.space = self.symbols['all_symbols']
         self.blank = re.compile('\r')
@@ -189,7 +190,7 @@ class LongHandlerEN(Operation):
     def dialog_handler(self, state: EnSequence) -> Tuple[int, bool]:
         org_pointer = state.v_pointer
         sub_len = 0
-        for i in range(state.sentence_start + 1, state.v_pointer - 1):
+        for i in range(state.sentence_start + 1, org_pointer):
             state.v_pointer = i
             if not self.space.match(state[i]):
                 sub_len += 1
@@ -197,9 +198,9 @@ class LongHandlerEN(Operation):
                     state) and sub_len > self.min_sentence_length:
                 state.v_pointer = org_pointer
                 return i, True
-            if self.is_right_quota(state):
+            if self.is_right_quota(state) and sub_len > self.min_sentence_length:
                 state.v_pointer = org_pointer
-                return i, True
+                return max(i - 2, 0), True
         else:
             state.v_pointer = org_pointer
             return -1, False
